==> haskell-servant-server-0.20.3.0-25-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-servant-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 servant-server
version:              0.20.3.0
visibility:           public
id:                   servant-server-0.20.3.0-IdMcitVu2QsAIPAZGTbWBk
key:                  servant-server-0.20.3.0-IdMcitVu2QsAIPAZGTbWBk
license:              BSD-3-Clause
copyright:
    2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors

maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:             http://docs.servant.dev/
synopsis:
    A family of combinators for defining webservices APIs and serving them

description:
    A family of combinators for defining webservices APIs and serving them
    .
    You can learn about the basics in the <http://docs.servant.dev/en/stable/tutorial/index.html tutorial>.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant-server/example/greet.hs Here>
    is a runnable example, with comments, that defines a dummy API and implements
    a webserver that serves this API, using this package.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant-server/CHANGELOG.md CHANGELOG>

category:             Servant, Web
abi:                  7ba0f80b24337948964a34f47098ea85
exposed:              True
exposed-modules:
    Servant Servant.Server Servant.Server.Experimental.Auth
    Servant.Server.Generic Servant.Server.Internal
    Servant.Server.Internal.BasicAuth Servant.Server.Internal.Context
    Servant.Server.Internal.Delayed Servant.Server.Internal.DelayedIO
    Servant.Server.Internal.ErrorFormatter
    Servant.Server.Internal.Handler
    Servant.Server.Internal.ResponseRender
    Servant.Server.Internal.RouteResult Servant.Server.Internal.Router
    Servant.Server.Internal.RoutingApplication
    Servant.Server.Internal.ServerError Servant.Server.StaticFiles
    Servant.Server.UVerb Servant.Utils.StaticFiles

import-dirs:          /usr/lib/ghc-9.4.8/site-local/servant-server-0.20.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/servant-server-0.20.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/servant-server-0.20.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-servant-server
hs-libraries:         HSservant-server-0.20.3.0-IdMcitVu2QsAIPAZGTbWBk
depends:
    base-4.17.2.1 base64-bytestring-1.2.1.0-Fa0BuK0N9mu9JPJP7gaxRT
    bytestring-0.11.5.3 constraints-0.14.2-1QQNMMihZvL7jPWzLI9hpf
    containers-0.6.7 exceptions-0.10.5 filepath-1.4.2.2
    http-api-data-0.6.1-FahDGTMw50P4NKEAb3IwkU
    http-media-0.8.1.1-F5mdsuADoqm1fkscHywvqG
    http-types-0.12.4-Kfgn5nq0Uw5JM2IxBj4ZY1
    monad-control-1.0.3.1-GptxzQqshh7J2Y4ewMk2Hl mtl-2.2.2
    network-3.1.4.0-BMQQjwbPvFR57Ka0tgIiy2
    resourcet-1.2.6-KOK8YcGoRtO4DzojWOYtyP
    servant-0.20.3.0-GOIaCeayVrDJ22GgZs5cgj
    sop-core-0.5.0.2-6A7lf58QPy2GZuvhMdgskj
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C text-2.0.2 transformers-0.5.6.2
    transformers-base-0.4.6-9DQJFK0WHcQ1sjDWa6wyhD
    wai-3.2.4-LnpkwzoHUW9G2cGUC0nKUm
    wai-app-static-3.1.9-Glm2Lw7sTGQFOpqdgiTlrW
    word8-0.1.3-H2XlNdB8B5CGwrdA9Iis9I

haddock-interfaces:
    /usr/share/doc/haskell-servant-server/html/servant-server.haddock

haddock-html:         /usr/share/doc/haskell-servant-server/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-servant-server-0.20.3.0-52-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-servant-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 servant-server
version:              0.20.3.0
visibility:           public
id:                   servant-server-0.20.3.0-1e8jhSipIohFgQd8h6gmP4
key:                  servant-server-0.20.3.0-1e8jhSipIohFgQd8h6gmP4
license:              BSD-3-Clause
copyright:
    2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors

maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:             http://docs.servant.dev/
synopsis:
    A family of combinators for defining webservices APIs and serving them

description:
    A family of combinators for defining webservices APIs and serving them
    .
    You can learn about the basics in the <http://docs.servant.dev/en/stable/tutorial/index.html tutorial>.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant-server/example/greet.hs Here>
    is a runnable example, with comments, that defines a dummy API and implements
    a webserver that serves this API, using this package.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant-server/CHANGELOG.md CHANGELOG>

category:             Servant, Web
abi:                  e53c57ec902d6e19d6c4f875c8be9a20
exposed:              True
exposed-modules:
    Servant Servant.Server Servant.Server.Experimental.Auth
    Servant.Server.Generic Servant.Server.Internal
    Servant.Server.Internal.BasicAuth Servant.Server.Internal.Context
    Servant.Server.Internal.Delayed Servant.Server.Internal.DelayedIO
    Servant.Server.Internal.ErrorFormatter
    Servant.Server.Internal.Handler
    Servant.Server.Internal.ResponseRender
    Servant.Server.Internal.RouteResult Servant.Server.Internal.Router
    Servant.Server.Internal.RoutingApplication
    Servant.Server.Internal.ServerError Servant.Server.StaticFiles
    Servant.Server.UVerb Servant.Utils.StaticFiles

import-dirs:          /usr/lib/ghc-9.4.8/site-local/servant-server-0.20.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/servant-server-0.20.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/servant-server-0.20.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-servant-server
hs-libraries:         HSservant-server-0.20.3.0-1e8jhSipIohFgQd8h6gmP4
depends:
    base-4.17.2.1 base64-bytestring-1.2.1.0-G8BjkxE58WI1uqeVjCB0n4
    bytestring-0.11.5.3 constraints-0.14.2-Fcc8FwY8waN8FnX72pAilZ
    containers-0.6.7 exceptions-0.10.5 filepath-1.4.2.2
    http-api-data-0.6.1-Ct3YGnpgXQS6uC3vp2y6CM
    http-media-0.8.1.1-75g3Noac7YSCbog0lXG15E
    http-types-0.12.4-3Rkn4NOOYhzvBVdRap5Ii
    monad-control-1.0.3.1-5KQQUvViYP35kwtWEUOPGs mtl-2.2.2
    network-3.1.4.0-2g2oEkgQCahBaM3HvlpVNW
    resourcet-1.2.6-7JBHLKMrq1iCQRZHHoRMKl
    servant-0.20.3.0-5yfHPrFnFIjC5udvdKPgHT
    sop-core-0.5.0.2-6A7lf58QPy2GZuvhMdgskj
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C text-2.0.2 transformers-0.5.6.2
    transformers-base-0.4.6-72fNkPW8m0RFmUAZLkd9QA
    wai-3.2.4-GKgviHtnWhO3KoBTtmAmpl
    wai-app-static-3.1.9-HQN6tAEXe3G2u36LT6d9l9
    word8-0.1.3-H2XlNdB8B5CGwrdA9Iis9I

haddock-interfaces:
    /usr/share/doc/haskell-servant-server/html/servant-server.haddock

haddock-html:         /usr/share/doc/haskell-servant-server/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
